@@ -168,37 +168,53 @@ for(i=nbits-1;i>=0;i--) /* always requires less number of bits */
 }
 
 
-static void cvt_fpsdec(Trptr t, TimeType val, char *os, int len)
+static void cvt_fpsdec(Trptr t, TimeType val, char *os, int len, int nbits)
 {
 int shamt = t->t_fpdecshift;
 TimeType lpart = val >> shamt;
 TimeType rmsk = (1 << shamt);
 TimeType rbit = (val >= 0) ? (val & (rmsk-1)) : ((-val) & (rmsk-1));
 double rfrac;
+int negflag = 0;
 char dbuf[32];
 char bigbuf[64];
 
-if(rmsk)
-	{
-	rfrac = (double)rbit / (double)rmsk;
-	}
-	else
-	{
-	rfrac = 0.0;
-	}			
 
-sprintf(dbuf, "%.16g", rfrac);			
+if(rmsk)
+        {
+        rfrac = (double)rbit / (double)rmsk;
+
+        if(shamt)
+                {
+                if(lpart < 0)
+                        {
+                        if(rbit)
+                                {
+                                lpart++;
+                                if(!lpart) negflag = 1;
+                                }
+                        }
+                }
+
+        }
+        else
+        {
+        rfrac = 0.0;
+        }
+
+sprintf(dbuf, "%.16g", rfrac);
 char *dot = strchr(dbuf, '.');
+
 if(dot && (dbuf[0] == '0'))
-	{
-	sprintf(bigbuf, TTFormat".%s", lpart, dot+1);
-	strncpy(os, bigbuf, len);
-	os[len-1] = 0;
-	}
-	else
-	{
-	sprintf(os, TTFormat, lpart);
-	}
+        {
+	sprintf(bigbuf, "%s"TTFormat".%s", negflag ? "-" : "", lpart, dot+1);
+        strncpy(os, bigbuf, len);
+        os[len-1] = 0;
+        }
+        else
+        {
+	sprintf(os, "%s"TTFormat, negflag ? "-" : "", lpart);
+        }
 }
 
 static void cvt_fpsudec(Trptr t, TimeType val, char *os, int len)
@@ -674,7 +690,7 @@ else if(flags&TR_SIGNED)
 		{
 		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
 			{
-			cvt_fpsdec(t, val, os, len);
+			cvt_fpsdec(t, val, os, len, nbits);
 			}
 			else
 			{
@@ -1376,7 +1392,7 @@ else if(flags&TR_SIGNED)
 		{
 		if((flags&TR_FPDECSHIFT)&&(t->t_fpdecshift))
 			{
-			cvt_fpsdec(t, val, os, len);
+			cvt_fpsdec(t, val, os, len, nbits);
 			}
 			else
 			{
@@ -1747,55 +1763,80 @@ if(flags&TR_REVERSE)
 	for(i=0;i<3;i++) *(fwdpnt2++)=xfwd[0];
 	}
 
-if(flags&TR_SIGNED)
+if(flags&TR_REAL)
 	{
-	char *parse;
-	TimeType val = 0;
-	unsigned char fail=0;
-
-	parse=newbuff+3;
-	cvt_gray(flags,parse,nbits);
-
-        if((parse[0]==AN_1)||(parse[0]==AN_H))
-                { val = LLDescriptor(-1); }
-        else
-        if((parse[0]==AN_0)||(parse[0]==AN_L))
-                { val = LLDescriptor(0); }
-        else
-                { fail = 1; }
-
-        if(!fail)
-	for(i=1;i<nbits;i++)
+	if(nbits==64) /* fail (NaN) otherwise */
 		{
-		val<<=1;
+		char *parse;
+		UTimeType val=0;
+		unsigned char fail=0;
 
-                if((parse[i]==AN_1)||(parse[i]==AN_H)) {  val|=LLDescriptor(1); }
-                else if((parse[i]!=AN_0)&&(parse[i]!=AN_L)) { fail=1; break; }
-		}
-	if(!fail)
-		{
-		retval = val;
+		parse=newbuff+3;
+		for(i=0;i<nbits;i++)
+			{
+			val<<=1;
+
+	        if((parse[i]==AN_1)||(parse[i]==AN_H)) {  val|=LLDescriptor(1); }
+	        else if((parse[i]!=AN_0)&&(parse[i]!=AN_L)) { fail=1; break; }
+			}
+		if(!fail)
+			{
+			retval = *(double *)&val;
+			}
 		}
 	}
-else	/* decimal when all else fails */
-	{
-	char *parse;
-	UTimeType val=0;
-	unsigned char fail=0;
-
-	parse=newbuff+3;
-	cvt_gray(flags,parse,nbits);
-
-	for(i=0;i<nbits;i++)
+    else
+    {
+	if(flags&TR_SIGNED)
 		{
-		val<<=1;
+		char *parse;
+		TimeType val = 0;
+		unsigned char fail=0;
 
-                if((parse[i]==AN_1)||(parse[i]==AN_H)) {  val|=LLDescriptor(1); }
-                else if((parse[i]!=AN_0)&&(parse[i]!=AN_L)) { fail=1; break; }
+		parse=newbuff+3;
+		cvt_gray(flags,parse,nbits);
+
+	        if((parse[0]==AN_1)||(parse[0]==AN_H))
+	                { val = LLDescriptor(-1); }
+	        else
+	        if((parse[0]==AN_0)||(parse[0]==AN_L))
+	                { val = LLDescriptor(0); }
+	        else
+	                { fail = 1; }
+
+	        if(!fail)
+		for(i=1;i<nbits;i++)
+			{
+			val<<=1;
+
+	                if((parse[i]==AN_1)||(parse[i]==AN_H)) {  val|=LLDescriptor(1); }
+	                else if((parse[i]!=AN_0)&&(parse[i]!=AN_L)) { fail=1; break; }
+			}
+		if(!fail)
+			{
+			retval = val;
+			}
 		}
-	if(!fail)
+	else	/* decimal when all else fails */
 		{
-		retval = val;
+		char *parse;
+		UTimeType val=0;
+		unsigned char fail=0;
+
+		parse=newbuff+3;
+		cvt_gray(flags,parse,nbits);
+
+		for(i=0;i<nbits;i++)
+			{
+			val<<=1;
+
+	                if((parse[i]==AN_1)||(parse[i]==AN_H)) {  val|=LLDescriptor(1); }
+	                else if((parse[i]!=AN_0)&&(parse[i]!=AN_L)) { fail=1; break; }
+			}
+		if(!fail)
+			{
+			retval = val;
+			}
 		}
 	}
 
