@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2013.
+ * Copyright (c) Tony Bybell 1999-2016.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -185,6 +185,13 @@ GLOBALS->do_initial_zoom_fit=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_dragzoom_threshold(char *str)
+{
+DEBUG(printf("f_dragzoom_threshold(\"%s\")\n",str));
+GLOBALS->dragzoom_threshold=atoi_64(str);
+return(0);
+}
+
 int f_dynamic_resizing(char *str)
 {
 DEBUG(printf("f_dynamic_resizing(\"%s\")\n",str));
@@ -293,6 +300,13 @@ GLOBALS->hide_sst=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_hier_ignore_escapes(char *str)
+{
+DEBUG(printf("f_hier_ignore_escapes(\"%s\")\n",str));
+GLOBALS->hier_ignore_escapes=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_keep_xz_colors(char *str)
 {
 DEBUG(printf("f_keep_xz_colors(\"%s\")\n",str));
@@ -843,6 +857,7 @@ static struct rc_entry rcitems[]=
 { "disable_mouseover", f_disable_mouseover },
 { "disable_tooltips", f_disable_tooltips },
 { "do_initial_zoom_fit", f_do_initial_zoom_fit },
+{ "dragzoom_threshold", f_dragzoom_threshold },
 { "dynamic_resizing", f_dynamic_resizing },
 { "editor", f_editor },
 { "enable_fast_exit", f_enable_fast_exit },
@@ -857,6 +872,7 @@ static struct rc_entry rcitems[]=
 { "hide_sst", f_hide_sst },
 { "hier_delimeter", f_hier_delimeter },
 { "hier_grouping", f_hier_grouping },
+{ "hier_ignore_escapes", f_hier_ignore_escapes },
 { "hier_max_level", f_hier_max_level },
 { "highlight_wavewindow", f_highlight_wavewindow },
 { "hpane_pack", f_hpane_pack },
@@ -963,6 +979,63 @@ f_color_ltblue	        ("5dbebb"); /* light blue    */
 f_color_gmstrd          ("7d8104"); /* green mustard */
 }
 
+int insert_rc_variable(char *str)
+{
+int i;
+int len;
+int ok = 0;
+
+len=strlen(str);
+if(len)
+	{
+	for(i=0;i<len;i++)
+		{
+		int pos;
+		if((str[i]==' ')||(str[i]=='\t')) continue;	/* skip leading ws */
+		if(str[i]=='#') break; 				/* is a comment */
+		for(pos=i;i<len;i++)
+			{
+			if((str[i]==' ')||(str[i]=='\t'))
+				{
+				str[i]=0; /* null term envname */
+
+				for(i=i+1;i<len;i++)
+					{
+					struct rc_entry *r;
+
+					if((str[i]==' ')||(str[i]=='\t')) continue;
+					if((r=bsearch((void *)(str+pos), (void *)rcitems,
+						sizeof(rcitems)/sizeof(struct rc_entry),
+						sizeof(struct rc_entry), rc_compare)))
+						{
+						int j;
+							for(j=len-1;j>=i;j--)
+							{
+							if((str[j]==' ')||(str[j]=='\t')) /* nuke trailing spaces */
+								{
+								str[j]=0;
+								continue;
+								}
+								else
+								{
+								break;
+								}
+							}
+						r->func(str+i); /* call resolution function */
+						ok = 1;
+						}
+					break;
+					}
+				break;	/* added so multiple word values work properly*/
+				}
+			}
+		break;
+		}
+	}
+
+return(ok);
+}
+
 
 void read_rc_file(char *override_rc)
 {
@@ -1077,55 +1150,7 @@ while(!feof(handle))
 	GLOBALS->rc_line_no++;
 	if((str=fgetmalloc(handle)))
 		{
-		int len;
-		len=strlen(str);
-		if(len)
-			{
-			for(i=0;i<len;i++)
-				{
-				int pos;
-				if((str[i]==' ')||(str[i]=='\t')) continue;	/* skip leading ws */
-				if(str[i]=='#') break; 				/* is a comment */
-				for(pos=i;i<len;i++)
-					{
-					if((str[i]==' ')||(str[i]=='\t'))
-						{
-						str[i]=0; /* null term envname */
-
-						for(i=i+1;i<len;i++)
-							{
-							struct rc_entry *r;
-
-							if((str[i]==' ')||(str[i]=='\t')) continue;
-							if((r=bsearch((void *)(str+pos), (void *)rcitems,
-								sizeof(rcitems)/sizeof(struct rc_entry),
-								sizeof(struct rc_entry), rc_compare)))
-								{
-								int j;
-
-								for(j=len-1;j>=i;j--)
-									{
-									if((str[j]==' ')||(str[j]=='\t')) /* nuke trailing spaces */
-										{
-										str[j]=0;
-										continue;
-										}
-										else
-										{
-										break;
-										}
-									}
-								r->func(str+i); /* call resolution function */
-								}
-							break;
-							}
-						break;	/* added so multiple word values work properly*/
-						}
-					}
-				break;
-				}
-
-			}
+		insert_rc_variable(str);
 		free_2(str);
 		}
 	}
@@ -1134,4 +1159,3 @@ fclose(handle);
 errno=0;
 return;
 }
-
